@@ -45,7 +45,7 @@ GauPro_Gauss <- R6::R6Class(classname = "GauPro_Gauss",
        #theta_short_length = NULL,
        separable = NULL,
        initialize = function(X, Z, verbose=0, separable=T, useC=F,useGrad=T,
-                             parallel=T,
+                             parallel=FALSE,
                              nug=1e-6, nug.min=1e-8, nug.est=T,
                              param.est=T,
                              theta = NULL, theta_short = NULL, theta_map = NULL,
