@@ -64,7 +64,7 @@ GauPro_kernel_model <- R6::R6Class(classname = "GauPro",
         verbose = 0,
         useC = TRUE,
         useGrad = FALSE,
-        parallel = FALSE,
+        parallel = NULL,
         parallel_cores = NULL,
         restarts = NULL,
         #deviance_out = NULL, #(theta, nug)
@@ -73,7 +73,7 @@ GauPro_kernel_model <- R6::R6Class(classname = "GauPro",
         initialize = function(X, Z,
                               kernel, trend,
                               verbose=0, useC=F,useGrad=T,
-                              parallel=T,
+                              parallel=FALSE,
                               nug=1e-6, nug.min=1e-8, nug.max=Inf, nug.est=TRUE,
                               param.est = TRUE, restarts = 5,
                               ...) {
